@@ -4,12 +4,12 @@ cartographic projections and coordinate transformations library.
 
 Download: http://python.org/pypi/pyproj
 
-Requirements: Python 3.6+.
+Requirements: Python 3.7+.
 
 Contact:  Jeffrey Whitaker <jeffrey.s.whitaker@noaa.gov>
 
 Copyright (c) 2006-2018, Jeffrey Whitaker.
-Copyright (c) 2019-2020, Open source contributors.
+Copyright (c) 2019-2021, Open source contributors.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy of
 this software and associated documentation files (the "Software"), to deal in
@@ -28,7 +28,7 @@ HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTIO
 OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """
-__version__ = "3.0.0.post1"
+__version__ = "3.2.0"
 __all__ = [
     "Proj",
     "Geod",
@@ -47,22 +47,35 @@ __all__ = [
 import warnings
 
 import pyproj.network
-from pyproj._datadir import (  # noqa: F401
+from pyproj._datadir import (  # noqa: F401 pylint: disable=unused-import
     _pyproj_global_context_initialize,
     set_use_global_context,
 )
-from pyproj._show_versions import show_versions  # noqa: F401
-from pyproj.crs import CRS  # noqa: F401
-from pyproj.database import get_authorities, get_codes, get_units_map  # noqa: F401
-from pyproj.exceptions import DataDirError, ProjError  # noqa: F401
-from pyproj.geod import Geod, geodesic_version_str, pj_ellps  # noqa: F401
-from pyproj.list import (  # noqa: F401
+from pyproj._show_versions import (  # noqa: F401 pylint: disable=unused-import
+    show_versions,
+)
+from pyproj.crs import CRS  # noqa: F401 pylint: disable=unused-import
+from pyproj.database import (  # noqa: F401 pylint: disable=unused-import
+    get_authorities,
+    get_codes,
+    get_units_map,
+)
+from pyproj.exceptions import (  # noqa: F401 pylint: disable=unused-import
+    DataDirError,
+    ProjError,
+)
+from pyproj.geod import (  # noqa: F401 pylint: disable=unused-import
+    Geod,
+    geodesic_version_str,
+    pj_ellps,
+)
+from pyproj.list import (  # noqa: F401 pylint: disable=unused-import
     get_ellps_map,
     get_prime_meridians_map,
     get_proj_operations_map,
 )
-from pyproj.proj import Proj, pj_list  # noqa: F401
-from pyproj.transformer import (  # noqa: F401
+from pyproj.proj import Proj, pj_list  # noqa: F401 pylint: disable=unused-import
+from pyproj.transformer import (  # noqa: F401 pylint: disable=unused-import
     Transformer,
     itransform,
     proj_version_str,
